@@ -5,25 +5,50 @@ import shutil
 import sys
 import urllib
 import webbrowser
+import subprocess
 from os import listdir, path, system
 
 import simplejson
 
 import util
 from util import console
+from github import GitHub
 
 class Bat(object):
 
     CURR_SCRIPT = ''
-    GITHUB_VIM_REPO = 'http://github.com/api/v2/json/repos/watched/vim-scripts'
     PATHOGEN_URL = 'http://github.com/vim-scripts/pathogen.vim/raw/master/plugin/pathogen.vim'
     VIM_PATH = path.join(path.expanduser('~'), '.vim')
     AUTOLOAD_PATH = path.join(VIM_PATH, 'autoload')
     VIMPYRE_PATH = path.join(VIM_PATH, 'vimpyre')
-    VIMPYRE_DB_PATH = path.join(VIM_PATH, 'vimpyre.json')
 
     def __init__(self, script = ''):
         self.CURR_SCRIPT = script
+        self.github = GitHub()
+
+    def _check_name(self):
+        if self.CURR_SCRIPT.startswith('http') or self.CURR_SCRIPT.startswith('git'):
+            return self.CURR_SCRIPT
+
+        try:
+            search_ret = self.search()
+            rets = [item for item in search_ret if self.CURR_SCRIPT == item['name']]
+            if rets:
+                return rets[0]
+            return []
+        except:
+            pass
+
+    def _filter_script_name(self):
+        return self.CURR_SCRIPT.split('/')[-1]
+
+    def _render_fetch_url(self, ret):
+        if type(ret) == dict:
+            fetch_url = ret['url'] + '.git'
+        else:
+            fetch_url = ret
+
+        return fetch_url
 
     @property
     def bundles(self):
@@ -33,7 +58,6 @@ class Bat(object):
                 return [item for item in listdir('.') if path.isdir(item)]
         except OSError:
             console('Cannot access your vimpyre path!')
-            console('Please use `vimpyre init; vimpyre syncdb` first!')
 
     def install_base(self):
         """
@@ -62,34 +86,14 @@ class Bat(object):
         except:
             console('[Unexpected Error] Catch fail! Please try again!')
 
-    def syncdb(self):
-        """
-        Fetch http://github.com/api/v2/json/repos/show/vim-scripts
-
-            >>> bat = Bat('')
-            >>> bat.syncdb()
-            => => Send a bat to sync vim-scripts repo ...
-            Sync repo done!
-        """
-        try:
-            console('=> => Send a bat to sync vim-scripts repo ...')
-            raw_urlopen = urllib.urlopen(self.GITHUB_VIM_REPO)
-            if raw_urlopen.getcode() == 200:
-                raw_json = raw_urlopen.read()
-                with open(self.VIMPYRE_DB_PATH, 'w') as f:
-                    f.write(raw_json)
-                console('Sync repo done!')
-            else:
-                console('Sync repo fail! Please try again!')
-        except:
-            console('[Unexpected Error] Sync repo fail! Please try again')
-
     def install(self):
         console('=> => Send a bat to catch %s' % self.CURR_SCRIPT)
+
         try:
             ret = self._check_name()
             if ret:
-                cmd_fetch = 'git clone --depth 1 %s' % (ret['url'] + '.git')
+                fetch_url = self._render_fetch_url(ret)
+                cmd_fetch = 'git clone --depth 1 %s' % fetch_url
                 util.mkdir_p(self.VIMPYRE_PATH)
                 with util.cd(self.VIMPYRE_PATH):
                     system(cmd_fetch)
@@ -99,12 +103,12 @@ class Bat(object):
                        self.CURR_SCRIPT)
                 console(msg)
         except:
+            raise
             self.install_base()
-            self.syncdb()
 
     def update(self):
         console('=> => Send a bat to update %s' % self.CURR_SCRIPT)
-        bundle_path = path.join(self.VIMPYRE_PATH, self.CURR_SCRIPT)
+        bundle_path = path.join(self.VIMPYRE_PATH, self._filter_script_name())
         if path.isdir(bundle_path):
             with util.cd(bundle_path):
                 system('git pull')
@@ -126,8 +130,8 @@ class Bat(object):
 
     def remove(self):
         console('=> => Send a bat to bite %s' % self.CURR_SCRIPT)
-        bundle_path = path.join(self.VIMPYRE_PATH, self.CURR_SCRIPT)
-        if self._check_name() and path.isdir(bundle_path):
+        bundle_path = path.join(self.VIMPYRE_PATH, self._filter_script_name())
+        if path.isdir(bundle_path):
             shutil.rmtree(bundle_path)
             console('%s removed!' % self.CURR_SCRIPT)
         else:
@@ -146,53 +150,7 @@ class Bat(object):
         else:
             console('Please remove %s/pathogen.vim manually and clean `call pathogen#runtime_append_all_bundles("vimpyre")` from your .vimrc!' % self.AUTOLOAD_PATH)
             console('')
-            console('If you wish to use vimpyre to manage your vim scripts again, you need to use `vimpyre init; vimpyre syncdb` first!')
-
-    def list_installed(self):
-        console('=> => Send bats to collect all your vim-scripts')
-        if not self.bundles:
-            console('No vim-scripts found!')
-            sys.exit(1)
-
-        db = self._load_db()
-        for bundle in self.bundles:
-            found = False
-            for repo in db['repositories']:
-                if bundle == repo['name']:
-                    console('\033[1m%s\033[m => %s' % (repo['name'].encode('utf-8'), repo['description'].encode('utf-8')))
-                    found = True
-                    break
-
-            if not found:
-                console('\033[1m%s\033[m' % bundle.encode('utf-8'))
-
-    def _load_db(self):
-        """ Loads vim-scripts repository data from GitHub JSON """
-        try:
-            db = simplejson.loads(open(self.VIMPYRE_DB_PATH,'r').read())
-            assert 'repositories' in db
-            return db
-        except (IOError, simplejson.JSONDecodeError, AssertionError):
-            console('Missing or invalid vimpyre script database -- please run `vimpyre syncdb`!')
-            sys.exit(1)
-
-    def _check_name(self):
-        try:
-            search_ret = self.search()
-            rets = [item for item in search_ret if self.CURR_SCRIPT == item['name']]
-            if rets:
-                return rets[0]
-            return []
-        except:
-            pass
-
-    def list_all(self):
-        db = self._load_db()
-        for item in db['repositories']:
-            if path.isdir(path.join(self.VIMPYRE_PATH, item['name'])):
-                console('%s => %s [installed]' % (item['name'].encode('utf-8'), item['description'].encode('utf-8')))
-            else:
-                console('%s => %s' % (item['name'].encode('utf-8'), item['description'].encode('utf-8')))
+            console('If you wish to use vimpyre to manage your vim scripts again, you need to use `vimpyre init` first!')
 
     def search(self):
         """
@@ -205,8 +163,10 @@ class Bat(object):
             >>> bat.search() # doctest: +ELLIPSIS
             [{..., 'name': 'pathogen.vim'}]
         """
-        db = self._load_db()
-        return [item for item in db['repositories']
+
+        rets = self.github.search(self.CURR_SCRIPT)
+
+        return [item for item in rets
                 if self.CURR_SCRIPT.lower() in item['name'].lower()
                 or self.CURR_SCRIPT.lower() in item['description'].lower()]
 
@@ -218,3 +178,14 @@ class Bat(object):
         else:
             console('Sorry, no homepage found for this script.')
 
+    def list_installed(self):
+        console('=> => Send bats to collect all your vim-scripts')
+        if not self.bundles:
+            console('No vim-scripts found!')
+            sys.exit(1)
+
+        for bundle in self.bundles:
+            bundle_path = path.join(self.VIMPYRE_PATH, bundle)
+            with util.cd(bundle_path):
+                url = subprocess.check_output(['grep', 'url', '.git/config']).replace('\turl = ', '').replace('\n', '')
+                console('\033[1m%s\033[m => %s' % (bundle, url))
